hyper_snackbar library

Classes

HyperConfig
Configuration class for customizing the appearance and behavior of HyperSnackbar.
HyperSnackAction
Represents an action button displayed within the snackbar.
HyperSnackbar
A static manager class for displaying and managing HyperSnackbars.

Enums

HyperSnackAnimationType
Defines the entrance and exit animation styles.
HyperSnackDisplayMode
Defines the display mode of the snackbar.
HyperSnackPosition
Defines the vertical position where the snackbar will appear.
SnackPosition
GetX compatible alias for snackbar position.

Extensions

HyperSnackbarExtensions on BuildContext
Extension methods for BuildContext.