HyperSnackAction class
Represents an action button displayed within the snackbar.
Constructors
- HyperSnackAction({required String label, required VoidCallback onPressed, Color? textColor, Color? backgroundColor, bool autoDismiss = true})
-
const
Properties
- autoDismiss → bool
-
Whether to close the snackbar automatically when the action is pressed.
final
- backgroundColor → Color?
-
The background color of the action button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The text label for the button.
final
- onPressed → VoidCallback
-
The callback function executed when the button is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
The color of the action button's text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited